#
# spec file for package python-SoundFile
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-SoundFile
Version:        0.12.1
Release:        1.5
Summary:        An audio library based on libsndfile, CFFI and NumPy
License:        BSD-3-Clause
URL:            https://github.com/bastibe/python-soundfile
Source:         https://files.pythonhosted.org/packages/source/s/soundfile/soundfile-%{version}.tar.gz
Source99:       python-SoundFile.rpmlintrc
BuildRequires:  %{python_module cffi >= 1.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libsndfile-devel
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-cffi >= 1.0
Requires:       %(rpm -q --requires libsndfile-devel | grep -o 'libsndfile[0-9]*')
Recommends:     python-numpy
Obsoletes:      python-PySoundFile < %{version}
Provides:       python-PySoundFile = %{version}
Provides:       python-soundfile = %{version}
%python_subpackages

%description
PySoundFile is an audio library based on libsndfile, CFFI and NumPy.
Full documentation is available on http://pysoundfile.readthedocs.org/.

PySoundFile can read and write sound files. File reading/writing is
supported through libsndfile, which itself is accessed through CFFI,
a foreign function interface for Python calling C code. PySoundFile
represents audio data as NumPy arrays.

%prep
%setup -q -n soundfile-%{version}

%build
# force a pure wheel through unknown platform
# (we do not bundle the libs anyway)
export PYSOUNDFILE_PLATFORM="OBS"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/soundfile-%{version}.dist-info
%{python_sitelib}/soundfile.py
%{python_sitelib}/_soundfile.py
%pycache_only %{python_sitelib}/__pycache__/soundfile*.pyc
%pycache_only %{python_sitelib}/__pycache__/_soundfile*.pyc

%changelog
* Sat Apr  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.12.1
  * Fixes a bug in the library discover on Linux, if no system
    library and no packaged library could be found.
- Release 0.12.0
  * Updated libsndfile to v1.2.0
  * Improves precompiled library location, especially with py2app
    or cx-freeze.
  * Now provide binary wheels for Linux x86_64
  * Now prefers packaged libsndfile over system-installed
    libsndfile
- Release 0.11.0
  * MP3 support
  * Updates libsndfile to v1.1.0
  * Adds get_strings method for retrieving all metadata at once
  * Improves documentation, error messages and tests
  * Displays length of very short files in samples
  * Supports the file system path protocol (pathlib et al)
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Don't install and test optional numpy on python36 flavor,
  because NumPy 1.20 on Tumbleweed does not support Python 3.6
  anymore (NEP 29)
* Wed Mar  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix pytest dependency
* Mon Dec  2 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.10.3.post1
  * Update Python versions in .travis.yml
  * improve _check_dtype exception
  * add display sound file length in samples
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Fri Aug  9 2019 Todd R <toddrme2178@gmail.com>
- Restrict pytest version to fix tests.
* Fri Aug 17 2018 tchvatal@suse.com
- Sort out the header a bit
- Remove test conditional, always run tests
- Mark the package as noarch (as it is)
  * one test is failing on i586, but it is bug in libsndfile, disabled for now
    ret [ 32767, -32768, -32767, -1, -1, 0, 0, 0, 1, 1, 32766, 32767, 32767]
    exp (-32768, -32768, -32767, -1, -1, 0, 0, 0, 1, 1, 32766, 32767, 32767)
    https://github.com/bastibe/SoundFile/issues/185
* Fri May 18 2018 jengelh@inai.de
- Do not repeat other packages' metadata in description.
* Wed May  9 2018 toddrme2178@gmail.com
- Update to 0.10.2
  * Should now work with cx_freeze.
  * Several documentation fixes in the README.
  * Removes deprecated ctype argument in favor of dtype in buffer_*().
  * Adds SoundFile.frames in favor of now-deprecated __len__().
  * Improves performance of blocks and SoundFile.blocks().
  * Improves import time by using CFFI's out of line mode.
  * Adds a build script for building distributions.
* Wed Aug  9 2017 toddrme2178@gmail.com
- Not compatible with some architectures
* Tue Aug  8 2017 toddrme2178@gmail.com
- Initial version
